@@ -20,13 +20,14 @@ from .data import commands as commands_data
 from .commands import (
     command2callback,
     commands_summary,
+    command2syntax,
     groups,
     split_command_args,
     split_unknown_args,
 )
 from .completers import IRedisCompleter
 from .config import config
-from .exceptions import NotRedisCommand, InvalidArguments
+from .exceptions import NotRedisCommand, InvalidArguments, AmbiguousCommand
 from .renders import OutputRender
 from .utils import (
     compose_command_syntax,
@@ -106,6 +107,14 @@ class Client:
         else:
             config.no_version_reason = "--no-info flag activated"
 
+        if config.version and re.match(r"([\d\.]+)", config.version):
+            self.auth_compat(config.version)
+
+    def auth_compat(self, redis_version: str):
+        with_username = StrictVersion(redis_version) >= StrictVersion("6.0.0")
+        if with_username:
+            command2syntax["AUTH"] = "command_usernamex_password"
+
     def set_default_pager(self, config):
         configured_pager = config.pager
         os_environ_pager = os.environ.get("PAGER")
@@ -274,7 +283,7 @@ class Client:
         try:
             try:
                 command_name, args = split_command_args(redis_command)
-            except InvalidArguments:
+            except (InvalidArguments, AmbiguousCommand):
                 logger.warn(
                     "This is not a iredis known command, send to redis-server anyway..."
                 )
@@ -361,7 +370,7 @@ class Client:
             config.transaction = True
 
         if completer:
-            completer.update_completer_for_response(command_name, response)
+            completer.update_completer_for_response(command_name, args, response)
 
     def pre_hook(self, command, command_name, args, completer: IRedisCompleter):
         """
